# report.summary

`report.summary(models, digits=3)`

Print a summary of estimation results for each estimated model.

For each model, this method prints a header indicating the fixed-effects and the dependent variable, followed by a table of coefficient estimates with standard errors, t-values, and p-values.

## Parameters

Name | Type | Description | Default
--- | --- | --- | ---
`models` | list[Union[Feols, Fepois, Feiv]] or FixestMulti. | The models to be summarized. | required
`digits` | int | The number of decimal places to round the summary statistics to. Default is 3. | `3`

## Returns

Type | Description
--- | ---
None |

## Examples

    import pyfixest as pf

    # load data
    df = pf.get_data()
    fit1 = pf.feols("Y~X1 + X2 | f1", df)
    fit2 = pf.feols("Y~X1 + X2 | f1 + f2", df)
    fit3 = pf.feols("Y~X1 + X2 | f1 + f2 + f3", df)

    pf.summary([fit1, fit2, fit3])

    ###

    Estimation:  OLS
    Dep. var.: Y, Fixed effects: f1
    Inference:  CRV1
    Observations:  997

    | Coefficient   |   Estimate |   Std. Error |   t value |   Pr(>|t|) |   2.5% |   97.5% |
    |:--------------|-----------:|-------------:|----------:|-----------:|-------:|--------:|
    | X1            |     -0.950 |        0.067 |   -14.273 |      0.000 | -1.086 |  -0.813 |
    | X2            |     -0.174 |        0.018 |    -9.469 |      0.000 | -0.212 |  -0.137 |
    ---
    RMSE: 1.648 R2: 0.489 R2 Within: 0.239
    ###

    Estimation:  OLS
    Dep. var.: Y, Fixed effects: f1+f2
    Inference:  CRV1
    Observations:  997

    | Coefficient   |   Estimate |   Std. Error |   t value |   Pr(>|t|) |   2.5% |   97.5% |
    |:--------------|-----------:|-------------:|----------:|-----------:|-------:|--------:|
    | X1            |     -0.924 |        0.061 |   -15.165 |      0.000 | -1.049 |  -0.799 |
    | X2            |     -0.174 |        0.015 |   -11.918 |      0.000 | -0.204 |  -0.144 |
    ---
    RMSE: 1.346 R2: 0.659 R2 Within: 0.303
    ###

    Estimation:  OLS
    Dep. var.: Y, Fixed effects: f1+f2+f3
    Inference:  CRV1
    Observations:  997

    | Coefficient   |   Estimate |   Std. Error |   t value |   Pr(>|t|) |   2.5% |   97.5% |
    |:--------------|-----------:|-------------:|----------:|-----------:|-------:|--------:|
    | X1            |     -0.957 |        0.039 |   -24.645 |      0.000 | -1.037 |  -0.878 |
    | X2            |     -0.194 |        0.009 |   -21.730 |      0.000 | -0.212 |  -0.176 |
    ---
    RMSE: 0.97 R2: 0.823 R2 Within: 0.481